# libpythonpytools
Exemplo de construção de projetos Python - Curso Pytools

Suportado versão 3 de Python

[![Build Status](https://app.travis-ci.com/MarqueaneSouza/libpythonpytools.svg?branch=main)](https://app.travis-ci.com/MarqueaneSouza/libpythonpytools)

Tópicos a serem abordados: 
1. Git
2. Virtualenv
3. Pip


08-05 Branch 4 - teste aula Freature Branch
08-05 Instalação Teste - Arquivo Setup.py.
10-05 Teste
Instalação da lib twine